==> crisis-management-resources-v0.2-sources.jar: org/petalslink/seacloud/SeaCloud_WSOUIService.java <==
package org.petalslink.seacloud;

import com.petalslink.wsn.service.wsnproducer.NotificationProducer;
import org.petalslink.easiestdemo.wsoui.provided.AbstractTestImplementation;
import org.petalslink.easiestdemo.wsoui.provided.AbstractExchangeProcessor;
import org.petalslink.easiestdemo.wsoui.provided.Exchange;
import org.petalslink.easiestdemo.wsoui.provided.WSOUIService;
import org.petalslink.easiestdemo.wsoui.core.WSOUIException;
import java.net.URL;
import javax.xml.namespace.QName;
import javax.xml.ws.WebEndpoint;
import javax.xml.ws.WebServiceClient;
import javax.xml.ws.WebServiceFeature;
import javax.xml.ws.Service;

@WebServiceClient(
	wsdlLocation = "crisis/v3/SeaCloud.wsdl",
	targetNamespace = "http://www.petalslink.org/SeaCloud/",
	name = "SeaCloud")
public class SeaCloud_WSOUIService extends Service implements WSOUIService{

	private static URL WSDL_LOCATION;
	public final static QName SERVICE = new QName("http://www.petalslink.org/SeaCloud/", "SeaCloud");
	public final static QName SeaCloudSOAPEndpoint = new QName("http://www.petalslink.org/SeaCloud/", "SeaCloud");
	
	public static URL getWSDL_LOCATION() {
	  if(WSDL_LOCATION == null) {
	    WSDL_LOCATION = Thread.currentThread().getContextClassLoader().getResource("crisis/v3/SeaCloud.wsdl");
	    if(WSDL_LOCATION == null) {
	       throw new RuntimeException("Impossible to find wsdl in class loader at: crisis/v3/SeaCloud.wsdl");
	    } else {
	       System.out.println("WSDL localized at: " + WSDL_LOCATION + "");
	    }
	  }
	  return WSDL_LOCATION;
	}
	public SeaCloud_WSOUIService() {
		super(getWSDL_LOCATION(), SERVICE);
	}

	@WebEndpoint(name = "SeaCloudSOAPEndpoint")
	public NotificationProducer getSeaCloudSOAPEndpoint() {
	    return super.getPort(SeaCloudSOAPEndpoint, NotificationProducer.class);
	}
	
	
	@WebEndpoint(name = "SeaCloudSOAPEndpoint")
	public NotificationProducer getFiremenSOAP(WebServiceFeature... features) {
	    return super.getPort(SeaCloudSOAPEndpoint, NotificationProducer.class, features);
	}
	
	
	public URL getWsdlLocation() {
	    return WSDL_LOCATION;
	}

}

==> crisis-management-resources-v0.4-sources.jar: org/petalslink/seacloud/SeaCloud_WSOUIService.java <==
package org.petalslink.seacloud;

import com.petalslink.wsn.service.wsnproducer.NotificationProducer;
import org.petalslink.easiestdemo.wsoui.provided.AbstractTestImplementation;
import org.petalslink.easiestdemo.wsoui.provided.AbstractExchangeProcessor;
import org.petalslink.easiestdemo.wsoui.provided.Exchange;
import org.petalslink.easiestdemo.wsoui.provided.WSOUIService;
import org.petalslink.easiestdemo.wsoui.core.WSOUIException;
import java.net.URL;
import javax.xml.namespace.QName;
import javax.xml.ws.WebEndpoint;
import javax.xml.ws.WebServiceClient;
import javax.xml.ws.WebServiceFeature;
import javax.xml.ws.Service;

@WebServiceClient(
	wsdlLocation = "crisis/management/generated/SeaCloud.wsdl",
	targetNamespace = "http://www.petalslink.org/SeaCloud/",
	name = "SeaCloud")
public class SeaCloud_WSOUIService extends Service implements WSOUIService{

	private static URL WSDL_LOCATION;
	public final static QName SERVICE = new QName("http://www.petalslink.org/SeaCloud/", "SeaCloud");
	public final static QName SeaCloudSOAPEndpoint = new QName("http://www.petalslink.org/SeaCloud/", "SeaCloud");
	
	public static URL getWSDL_LOCATION() {
	  if(WSDL_LOCATION == null) {
	    WSDL_LOCATION = Thread.currentThread().getContextClassLoader().getResource("crisis/management/generated/SeaCloud.wsdl");
	    if(WSDL_LOCATION == null) {
	       throw new RuntimeException("Impossible to find wsdl in class loader at: crisis/management/generated/SeaCloud.wsdl");
	    } else {
	       System.out.println("WSDL localized at: " + WSDL_LOCATION + "");
	    }
	  }
	  return WSDL_LOCATION;
	}
	public SeaCloud_WSOUIService() {
		super(getWSDL_LOCATION(), SERVICE);
	}

	@WebEndpoint(name = "SeaCloudSOAPEndpoint")
	public NotificationProducer getSeaCloudSOAPEndpoint() {
	    return super.getPort(SeaCloudSOAPEndpoint, NotificationProducer.class);
	}
	
	
	@WebEndpoint(name = "SeaCloudSOAPEndpoint")
	public NotificationProducer getFiremenSOAP(WebServiceFeature... features) {
	    return super.getPort(SeaCloudSOAPEndpoint, NotificationProducer.class, features);
	}
	
	
	public URL getWsdlLocation() {
	    return WSDL_LOCATION;
	}

}
